Function extension_from_ascii_or_utf8_bytes

pub fn extension_from_ascii_or_utf8_bytes(
    path: &[u8],
    path_separator: u8,
) -> Option<&str>
Get the file extension from a path given as bytes (since there is no path from CStr to PathBuf, right?). If the extension can’t be decoded as UTF-8, returns None. Invalid encoding in other parts of the path does not matter, though (as long as the path_separator and b'.' are still encoded as such).